[or-cvs] r10543: scrub out some more references to the misnamed 'bridge' conc (tor/trunk/src/or)

arma at seul.org arma at seul.org
Sat Jun 9 05:17:33 UTC 2007


Author: arma
Date: 2007-06-09 01:17:33 -0400 (Sat, 09 Jun 2007)
New Revision: 10543

Modified:
   tor/trunk/src/or/connection_edge.c
   tor/trunk/src/or/directory.c
   tor/trunk/src/or/or.h
Log:
scrub out some more references to the misnamed 'bridge' concept


Modified: tor/trunk/src/or/connection_edge.c
===================================================================
--- tor/trunk/src/or/connection_edge.c	2007-06-09 04:35:51 UTC (rev 10542)
+++ tor/trunk/src/or/connection_edge.c	2007-06-09 05:17:33 UTC (rev 10543)
@@ -357,7 +357,7 @@
     if (c->type != CONN_TYPE_AP)
       continue;
     conn = TO_EDGE_CONN(c);
-    /* if it's an internal bridge connection, don't yell its status. */
+    /* if it's an internal linked connection, don't yell its status. */
     severity = (!conn->_base.addr && !conn->_base.port)
       ? LOG_INFO : LOG_NOTICE;
     seconds_idle = now - conn->_base.timestamp_lastread;
@@ -1908,13 +1908,13 @@
  * DOCDOC start_reading
  */
 edge_connection_t *
-connection_ap_make_bridge(char *address, uint16_t port,
-                          const char *digest, int command)
+connection_ap_make_link(char *address, uint16_t port,
+                        const char *digest, int command)
 {
   edge_connection_t *conn;
 
-  log_notice(LD_APP,"Making internal anonymized tunnel to %s:%d ...",
-             safe_str(address),port); /* XXXX020 Downgrade back to info. */
+  log_info(LD_APP,"Making internal anonymized tunnel to %s:%d ...",
+           safe_str(address),port);
 
   conn = TO_EDGE_CONN(connection_new(CONN_TYPE_AP, AF_INET));
   conn->_base.linked = 1; /* so that we can add it safely below. */
@@ -1952,7 +1952,7 @@
     return NULL;
   }
 
-  log_info(LD_APP,"... AP bridge created and connected.");
+  log_info(LD_APP,"... application connection created and linked.");
   return conn;
 }
 

Modified: tor/trunk/src/or/directory.c
===================================================================
--- tor/trunk/src/or/directory.c	2007-06-09 04:35:51 UTC (rev 10542)
+++ tor/trunk/src/or/directory.c	2007-06-09 05:17:33 UTC (rev 10543)
@@ -538,20 +538,20 @@
      */
     conn->dirconn_direct = 0;
     linked_conn =
-      connection_ap_make_bridge(conn->_base.address, conn->_base.port,
-                                digest,
-                                anonymized_connection ?
-                                  SOCKS_COMMAND_CONNECT :
-                                  SOCKS_COMMAND_CONNECT_DIR);
+      connection_ap_make_link(conn->_base.address, conn->_base.port,
+                              digest,
+                              anonymized_connection ?
+                                SOCKS_COMMAND_CONNECT :
+                                SOCKS_COMMAND_CONNECT_DIR);
     if (!linked_conn) {
-      log_warn(LD_NET,"Making AP bridge to dirserver failed.");
+      log_warn(LD_NET,"Making tunnel to dirserver failed.");
       connection_mark_for_close(TO_CONN(conn));
       return;
     }
     connection_link_connections(TO_CONN(conn), TO_CONN(linked_conn));
 
     if (connection_add(TO_CONN(conn)) < 0) {
-      log_warn(LD_NET,"Unable to add AP bridge to dirserver.");
+      log_warn(LD_NET,"Unable to add connection for link to dirserver.");
       connection_mark_for_close(TO_CONN(conn));
       return;
     }

Modified: tor/trunk/src/or/or.h
===================================================================
--- tor/trunk/src/or/or.h	2007-06-09 04:35:51 UTC (rev 10542)
+++ tor/trunk/src/or/or.h	2007-06-09 05:17:33 UTC (rev 10543)
@@ -2103,7 +2103,7 @@
 struct socks_request_t {
   /** Which version of SOCKS did the client use? One of "0, 4, 5" -- where
    * 0 means that no socks handshake ever took place, and this is just a
    * stub connection (e.g. see connection_ap_make_bridge()). */
   char socks_version;
   int command; /**< What is this stream's goal? One from the above list. */
   size_t replylen; /**< Length of <b>reply</b>. */
@@ -2439,8 +2439,8 @@
 int connection_ap_handshake_send_begin(edge_connection_t *ap_conn);
 int connection_ap_handshake_send_resolve(edge_connection_t *ap_conn);
 
-edge_connection_t  *connection_ap_make_bridge(char *address, uint16_t port,
-                                              const char *digest, int command);
+edge_connection_t  *connection_ap_make_link(char *address, uint16_t port,
+                                            const char *digest, int command);
 void connection_ap_handshake_socks_reply(edge_connection_t *conn, char *reply,
                                          size_t replylen,
                                          int endreason);
@@ -2679,8 +2679,6 @@
 #define UNNAMED_ROUTER_NICKNAME "Unnamed"
 
 int connection_dirserv_flushed_some(dir_connection_t *conn);
-void connection_dirserv_unlink_from_bridge(dir_connection_t *dir_conn);
-void connection_dirserv_stop_blocking_all_on_or_conn(or_connection_t *or_conn);
 
 int dirserv_add_own_fingerprint(const char *nickname, crypto_pk_env_t *pk);
 int dirserv_load_fingerprint_file(void);
@@ -2103,7 +2103,7 @@
   /** Which version of SOCKS did the client use? One of "0, 4, 5" -- where
    * 0 means that no socks handshake ever took place, and this is just a
-   * stub connection (e.g. see connection_ap_make_bridge()). */
+   * stub connection (e.g. see connection_ap_make_link()). */
   char socks_version;
   int command; /**< What is this stream's goal? One from the above list. */



More information about the tor-commits mailing list